% Auto-generated chapter 88 for bukhari
% Hadiths in this chapter: 21

\hadithdefcmd{bukhari}{6918}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏الَّذِينَ آمَنُوا وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ شَقَّ ذَلِكَ عَلَى أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَقَالُوا أَيُّنَا لَمْ يَلْبِسْ إِيمَانَهُ بِظُلْمٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيْسَ بِذَاكَ، أَلاَ تَسْمَعُونَ إِلَى قَوْلِ لُقْمَانَ ‏\{‏إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ‏\}‏‏"‏‏.‏\hadithno{6918}\hadithtrans{Narrated `Abdullah:When the Verse: 'It is those who believe and confuse not their belief with wrong (i.e., worshipping others besides Allah): (6.82) was revealed, it became very hard on the companions of the Prophet (ﷺ) and they said, "Who among us has not confused his belief with wrong (oppression)?" On that, Allah's Apostle said, "This is not meant (by the Verse). Don't you listen to Luqman's statement: 'Verily! Joining others in worship with Allah is a great wrong indeed}}
\hadithdefcmd{bukhari}{6919}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا الْجُرَيْرِيُّ، وَحَدَّثَنِي قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سَعِيدٌ الْجُرَيْرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَكْبَرُ الْكَبَائِرِ الإِشْرَاكُ بِاللَّهِ، وَعُقُوقُ الْوَالِدَيْنِ، وَشَهَادَةُ الزُّورِ، وَشَهَادَةُ الزُّورِ ـ ثَلاَثًا ـ أَوْ قَوْلُ الزُّورِ ‏"‏‏.‏ فَمَا زَالَ يُكَرِّرُهَا حَتَّى قُلْنَا لَيْتَهُ سَكَتَ‏.‏\hadithno{6919}\hadithtrans{Narrated Abu Bakra:The Prophet. said, "The biggest of the great sins are: To join others in worship with Allah, to be undutiful to one's parents, and to give a false witness." He repeated it thrice, or said, "....a false statement," and kept on repeating that warning till we wished he would stop saying it. (See Hadith No.7, Vol)}}
\hadithdefcmd{bukhari}{6920}{حَدَّثَنِي مُحَمَّدُ بْنُ الْحُسَيْنِ بْنِ إِبْرَاهِيمَ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، أَخْبَرَنَا شَيْبَانُ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا الْكَبَائِرُ قَالَ ‏"‏ الإِشْرَاكُ بِاللَّهِ ‏"‏‏.‏ قَالَ ثُمَّ مَاذَا قَالَ ‏"‏ ثُمَّ عُقُوقُ الْوَالِدَيْنِ ‏"‏‏.‏ قَالَ ثُمَّ مَاذَا قَالَ ‏"‏ الْيَمِينُ الْغَمُوسُ ‏"‏‏.‏ قُلْتُ وَمَا الْيَمِينُ الْغَمُوسُ قَالَ ‏"‏ الَّذِي يَقْتَطِعُ مَالَ امْرِئٍ مُسْلِمٍ هُوَ فِيهَا كَاذِبٌ ‏"‏‏.‏\hadithno{6920}\hadithtrans{Narrated `Abdullah bin `Amr:A bedouin came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! What are the biggest sins?: The Prophet (ﷺ) said, "To join others in worship with Allah." The bedouin said, "What is next?" The Prophet (ﷺ) said, "To be undutiful to one's parents." The bedouin said "What is next?" The Prophet (ﷺ) said "To take an oath 'Al-Ghamus." The bedouin said, "What is an oath 'Al-Ghamus'?" The Prophet (ﷺ) said, "The false oath through which one deprives a Muslim of his property (unjustly)}}
\hadithdefcmd{bukhari}{6921}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَنُؤَاخَذُ بِمَا عَمِلْنَا فِي الْجَاهِلِيَّةِ قَالَ ‏ "‏ مَنْ أَحْسَنَ فِي الإِسْلاَمِ لَمْ يُؤَاخَذْ بِمَا عَمِلَ فِي الْجَاهِلِيَّةِ، وَمَنْ أَسَاءَ فِي الإِسْلاَمِ أُخِذَ بِالأَوَّلِ وَالآخِرِ ‏"‏‏.‏\hadithno{6921}\hadithtrans{Narrated Ibn Mas`ud:A man said, "O Allah's Messenger (ﷺ)! Shall we be punished for what we did in the pre-Islamic Period of ignorance?" The Prophet (ﷺ) said, "Whoever does good in Islam will not be punished for what he did in the Pre-Islamic Period of ignorance and whoever does evil in Islam will be punished for his former and later (bad deeds)}}
\hadithdefcmd{bukhari}{6922}{حَدَّثَنَا أَبُو النُّعْمَانِ، مُحَمَّدُ بْنُ الْفَضْلِ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، قَالَ أُتِيَ عَلِيٌّ ـ رضى الله عنه ـ بِزَنَادِقَةٍ فَأَحْرَقَهُمْ فَبَلَغَ ذَلِكَ ابْنَ عَبَّاسٍ فَقَالَ لَوْ كُنْتُ أَنَا لَمْ أُحْرِقْهُمْ لِنَهْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَقَتَلْتُهُمْ لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏‏.‏\hadithno{6922}\hadithtrans{Narrated `Ikrima:Some Zanadiqa (atheists) were brought to `Ali and he burnt them. The news of this event, reached Ibn `Abbas who said, "If I had been in his place, I would not have burnt them, as Allah's Messenger (ﷺ) forbade it, saying, 'Do not punish anybody with Allah's punishment (fire).' I would have killed them according to the statement of Allah's Messenger (ﷺ), 'Whoever changed his Islamic religion, then kill him}}
\hadithdefcmd{bukhari}{6923}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ قُرَّةَ بْنِ خَالِدٍ، حَدَّثَنِي حُمَيْدُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبُو بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ أَقْبَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَمَعِي رَجُلاَنِ مِنَ الأَشْعَرِيِّينَ، أَحَدُهُمَا عَنْ يَمِينِي، وَالآخَرُ عَنْ يَسَارِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَاكُ فَكِلاَهُمَا سَأَلَ‏.‏ فَقَالَ ‏"‏ يَا أَبَا مُوسَى ‏"‏‏.‏ أَوْ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ ‏"‏‏.‏ قَالَ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أَطْلَعَانِي عَلَى مَا فِي أَنْفُسِهِمَا، وَمَا شَعَرْتُ أَنَّهُمَا يَطْلُبَانِ الْعَمَلَ‏.‏ فَكَأَنِّي أَنْظُرُ إِلَى سِوَاكِهِ تَحْتِ شَفَتِهِ قَلَصَتْ فَقَالَ ‏"‏ لَنْ ـ أَوْ ـ لاَ نَسْتَعْمِلُ عَلَى عَمَلِنَا مَنْ أَرَادَهُ، وَلَكِنِ اذْهَبْ أَنْتَ يَا أَبَا مُوسَى ـ أَوْ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ ـ إِلَى الْيَمَنِ ‏"‏‏.‏ ثُمَّ أَتْبَعَهُ مُعَاذُ بْنُ جَبَلٍ، فَلَمَّا قَدِمَ عَلَيْهِ أَلْقَى لَهُ وِسَادَةً قَالَ انْزِلْ، وَإِذَا رَجُلٌ عِنْدَهُ مُوثَقٌ‏.‏ قَالَ مَا هَذَا قَالَ كَانَ يَهُودِيًّا فَأَسْلَمَ ثُمَّ تَهَوَّدَ‏.‏ قَالَ اجْلِسْ‏.‏ قَالَ لاَ أَجْلِسُ حَتَّى يُقْتَلَ‏.‏ قَضَاءُ اللَّهِ وَرَسُولِهِ‏.‏ ثَلاَثَ مَرَّاتٍ، فَأَمَرَ بِهِ فَقُتِلَ، ثُمَّ تَذَاكَرْنَا قِيَامَ اللَّيْلِ، فَقَالَ أَحَدُهُمَا أَمَّا أَنَا فَأَقُومُ وَأَنَامُ، وَأَرْجُو فِي نَوْمَتِي مَا أَرْجُو فِي قَوْمَتِي‏.‏\hadithno{6923}\hadithtrans{Narrated Abu Burda:Abu Musa said, "I came to the Prophet (ﷺ) along with two men (from the tribe) of Ash`ariyin, one on my right and the other on my left, while Allah's Messenger (ﷺ) was brushing his teeth (with a Siwak), and both men asked him for some employment. The Prophet (ﷺ) said, 'O Abu Musa (O `Abdullah bin Qais!).' I said, 'By Him Who sent you with the Truth, these two men did not tell me what was in their hearts and I did not feel (realize) that they were seeking employment.' As if I were looking now at his Siwak being drawn to a corner under his lips, and he said, 'We never (or, we do not) appoint for our affairs anyone who seeks to be employed. But O Abu Musa! (or `Abdullah bin Qais!) Go to Yemen.'" The Prophet then sent Mu`adh bin Jabal after him and when Mu`adh reached him, he spread out a cushion for him and requested him to get down (and sit on the cushion). Behold: There was a fettered man beside Abu Muisa. Mu`adh asked, "Who is this (man)?" Abu Muisa said, "He was a Jew and became a Muslim and then reverted back to Judaism." Then Abu Muisa requested Mu`adh to sit down but Mu`adh said, "I will not sit down till he has been killed. This is the judgment of Allah and His Apostle (for such cases) and repeated it thrice. Then Abu Musa ordered that the man be killed, and he was killed. Abu Musa added, "Then we discussed the night prayers and one of us said, 'I pray and sleep, and I hope that Allah will reward me for my sleep as well as for my prayers}}
\hadithdefcmd{bukhari}{6925}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ، وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ، قَالَ عُمَرُ يَا أَبَا بَكْرٍ، كَيْفَ تُقَاتِلُ النَّاسَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ، إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ، فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ، وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ أَنْ قَدْ شَرَحَ اللَّهُ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏\hadithno{6925}\hadithtrans{Narrated Abu Huraira:When the Prophet (ﷺ) died and Abu Bakr became his successor and some of the Arabs reverted to disbelief, `Umar said, "O Abu Bakr! How can you fight these people although Allah's Messenger (ﷺ) said, 'I have been ordered to fight the people till they say: 'None has the right to be worshipped but Allah, 'and whoever said, 'None has the right to be worshipped but Allah', Allah will save his property and his life from me, unless (he does something for which he receives legal punishment) justly, and his account will be with Allah?' "Abu Bakr said, "By Allah! I will fight whoever differentiates between prayers and Zakat as Zakat is the right to be taken from property (according to Allah's Orders). By Allah! If they refused to pay me even a kid they used to pay to Allah's Messenger (ﷺ), I would fight with them for withholding it." `Umar said, "By Allah: It was nothing, but I noticed that Allah opened Abu Bakr's chest towards the decision to fight, therefore I realized that his decision was right}}
\hadithdefcmd{bukhari}{6926}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ مَرَّ يَهُودِيٌّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ السَّامُ عَلَيْكَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ ‏"‏‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَدْرُونَ مَا يَقُولُ قَالَ السَّامُ عَلَيْكَ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَلاَ نَقْتُلُهُ قَالَ ‏"‏ لاَ، إِذَا سَلَّمَ عَلَيْكُمْ أَهْلُ الْكِتَابِ فَقُولُوا وَعَلَيْكُمْ ‏"‏‏.‏\hadithno{6926}\hadithtrans{Narrated Anas bin Malik:A Jew passed by Allah's Messenger (ﷺ) and said, "As-Samu 'Alaika." Allah's Messenger (ﷺ) said in reply, "We 'Alaika." Allah's Messenger (ﷺ) then said to his companions, "Do you know what he (the Jew) has said? He said, 'As-Samu 'Alaika.'" They said, "O Allah's Messenger (ﷺ)! Shall we kill him?" The Prophet, said, "No. When the people of the Book greet you, say: 'Wa 'Alaikum}}
\hadithdefcmd{bukhari}{6927}{حَدَّثَنَا أَبُو نُعَيْمٍ، عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنَ رَهْطٌ مِنَ الْيَهُودِ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكَ‏.‏ فَقُلْتُ بَلْ عَلَيْكُمُ السَّامُ وَاللَّعْنَةُ‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ إِنَّ اللَّهَ رَفِيقٌ يُحِبُّ الرِّفْقَ فِي الأَمْرِ كُلِّهِ ‏"‏‏.‏ قُلْتُ أَوَلَمْ تَسْمَعْ مَا قَالُوا قَالَ ‏"‏ قُلْتُ وَعَلَيْكُمْ ‏"‏‏.‏\hadithno{6927}\hadithtrans{Narrated `Aisha:A group of Jews asked permission to visit the Prophet (and when they were admitted) they said, "As- Samu 'Alaika (Death be upon you)." I said (to them), "But death and the curse of Allah be upon you!" The Prophet (ﷺ) said, "O `Aisha! Allah is kind and lenient and likes that one should be kind and lenient in all matters." I said, "Haven't you heard what they said?" He said, "I said (to them), 'Wa 'Alaikum (and upon you)}}
\hadithdefcmd{bukhari}{6928}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، وَمَالِكِ بْنِ أَنَسٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْيَهُودَ إِذَا سَلَّمُوا عَلَى أَحَدِكُمْ إِنَّمَا يَقُولُونَ سَامٌ عَلَيْكَ‏.‏ فَقُلْ عَلَيْكَ ‏"‏‏.‏\hadithno{6928}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "When the Jews greet anyone of you they say: 'Sam'Alaika (death be upon you); so you should say; 'Wa 'Alaika (and upon you)}}
\hadithdefcmd{bukhari}{6929}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، قَالَ قَالَ عَبْدُ اللَّهِ كَأَنِّي أَنْظُرُ إِلَى النَّبِيِّ صلى الله عليه وسلم يَحْكِي نَبِيًّا مِنَ الأَنْبِيَاءِ ضَرَبَهُ قَوْمُهُ فَأَدْمَوْهُ، فَهْوَ يَمْسَحُ الدَّمَ عَنْ وَجْهِهِ وَيَقُولُ رَبِّ اغْفِرْ لِقَوْمِي، فَإِنَّهُمْ لاَ يَعْلَمُونَ‏.‏\hadithno{6929}\hadithtrans{Narrated `Abdullah:As if I am looking at the Prophet (ﷺ) while he was speaking about one of the prophets whose people have beaten and wounded him, and he was wiping the blood off his face and saying, "O Lord! Forgive my, people as they do not know}}
\hadithdefcmd{bukhari}{6930}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا خَيْثَمَةُ، حَدَّثَنَا سُوَيْدُ بْنُ غَفَلَةَ، قَالَ عَلِيٌّ ـ رضى الله عنه ـ إِذَا حَدَّثْتُكُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا فَوَاللَّهِ، لأَنْ أَخِرَّ مِنَ السَّمَاءِ أَحَبُّ إِلَىَّ مِنْ أَنْ أَكْذِبَ عَلَيْهِ، وَإِذَا حَدَّثْتُكُمْ فِيمَا بَيْنِي وَبَيْنَكُمْ فَإِنَّ الْحَرْبَ خَدْعَةٌ، وَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَيَخْرُجُ قَوْمٌ فِي آخِرِ الزَّمَانِ، حُدَّاثُ الأَسْنَانِ، سُفَهَاءُ الأَحْلاَمِ، يَقُولُونَ مِنْ خَيْرِ قَوْلِ الْبَرِيَّةِ، لاَ يُجَاوِزُ إِيمَانُهُمْ حَنَاجِرَهُمْ، يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، فَأَيْنَمَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ، فَإِنَّ فِي قَتْلِهِمْ أَجْرًا لِمَنْ قَتَلَهُمْ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{6930}\hadithtrans{Narrated `Ali:Whenever I tell you a narration from Allah's Messenger (ﷺ), by Allah, I would rather fall down from the sky than ascribe a false statement to him, but if I tell you something between me and you (not a Hadith) then it was indeed a trick (i.e., I may say things just to cheat my enemy). No doubt I heard Allah's Apostle saying, "During the last days there will appear some young foolish people who will say the best words but their faith will not go beyond their throats (i.e. they will have no faith) and will go out from (leave) their religion as an arrow goes out of the game. So, where-ever you find them, kill them, for who-ever kills them shall have reward on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6931}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، وَعَطَاءِ بْنِ يَسَارٍ، أَنَّهُمَا أَتَيَا أَبَا سَعِيدٍ الْخُدْرِيَّ فَسَأَلاَهُ عَنِ الْحَرُورِيَّةِ، أَسَمِعْتَ النَّبِيَّ صلى الله عليه وسلم‏.‏ قَالَ لاَ أَدْرِي مَا الْحَرُورِيَّةُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَخْرُجُ فِي هَذِهِ الأُمَّةِ ـ وَلَمْ يَقُلْ مِنْهَا ـ قَوْمٌ تَحْقِرُونَ صَلاَتَكُمْ مَعَ صَلاَتِهِمْ، يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حُلُوقَهُمْ ـ أَوْ حَنَاجِرَهُمْ ـ يَمْرُقُونَ مِنَ الدِّينِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ، فَيَنْظُرُ الرَّامِي إِلَى سَهْمِهِ إِلَى نَصْلِهِ إِلَى رِصَافِهِ، فَيَتَمَارَى فِي الْفُوقَةِ، هَلْ عَلِقَ بِهَا مِنَ الدَّمِ شَىْءٌ ‏"‏‏.‏\hadithno{6931}\hadithtrans{Narrated `Abdullah bin `Amr bin Yasar:That they visited Abu Sa`id Al-Khudri and asked him about Al-Harauriyya, a special unorthodox religious sect, "Did you hear the Prophet (ﷺ) saying anything about them?" Abu Sa`id said, "I do not know what Al-Harauriyya is, but I heard the Prophet (ﷺ) saying, "There will appear in this nation---- he did not say: From this nation ---- a group of people so pious apparently that you will consider your prayers inferior to their prayers, but they will recite the Qur'an, the teachings of which will not go beyond their throats and will go out of their religion as an arrow darts through the game, whereupon the archer may look at his arrow, its Nasl at its Risaf and its Fuqa to see whether it is blood-stained or not (i.e. they will have not even a trace of Islam in them)}}
\hadithdefcmd{bukhari}{6932}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانُ، حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ، أَنَّ أَبَاهُ، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ وَذَكَرَ الْحَرُورِيَّةَ ـ فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَمْرُقُونَ مِنَ الإِسْلاَمِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ ‏"‏‏.‏\hadithno{6932}\hadithtrans{Narrated `Abdullah bin `Umar:Regarding Al-Harauriyya: The Prophet (ﷺ) said, "They will go out of Islam as an arrow darts out of the game's body}}
\hadithdefcmd{bukhari}{6933}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَقْسِمُ جَاءَ عَبْدُ اللَّهِ بْنُ ذِي الْخُوَيْصِرَةِ التَّمِيمِيُّ فَقَالَ اعْدِلْ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ وَيْلَكَ مَنْ يَعْدِلُ إِذَا لَمْ أَعْدِلْ ‏"‏‏.‏ قَالَ عُمَرُ بْنُ الْخَطَّابِ دَعْنِي أَضْرِبْ عُنُقَهُ‏.‏ قَالَ ‏"‏ دَعْهُ فَإِنَّ لَهُ أَصْحَابًا يَحْقِرُ أَحَدُكُمْ صَلاَتَهُ مَعَ صَلاَتِهِ، وَصِيَامَهُ مَعَ صِيَامِهِ، يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، يُنْظَرُ فِي قُذَذِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، يُنْظَرُ فِي نَصْلِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، ثُمَّ يُنْظَرُ فِي رِصَافِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، ثُمَّ يُنْظَرُ فِي نَضِيِّهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، قَدْ سَبَقَ الْفَرْثَ وَالدَّمَ، آيَتُهُمْ رَجُلٌ إِحْدَى يَدَيْهِ ـ أَوْ قَالَ ثَدْيَيْهِ ـ مِثْلُ ثَدْىِ الْمَرْأَةِ ـ أَوْ قَالَ مِثْلُ الْبَضْعَةِ ـ تَدَرْدَرُ، يَخْرُجُونَ عَلَى حِينِ فُرْقَةٍ مِنَ النَّاسِ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ أَشْهَدُ سَمِعْتُ مِنَ النَّبِيِّ صلى الله عليه وسلم وَأَشْهَدُ أَنَّ عَلِيًّا قَتَلَهُمْ وَأَنَا مَعَهُ، جِيءَ بِالرَّجُلِ عَلَى النَّعْتِ الَّذِي نَعَتَهُ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ فَنَزَلَتْ فِيهِ ‏\{‏وَمِنْهُمْ مَنْ يَلْمِزُكَ فِي الصَّدَقَاتِ‏\}‏‏.‏\hadithno{6933}\hadithtrans{Narrated Abu Sa`id:While the Prophet (ﷺ) was distributing (something, `Abdullah bin Dhil Khawaisira at-Tamimi came and said, "Be just, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "Woe to you ! Who would be just if I were not?" `Umar bin Al-Khattab said, "Allow me to cut off his neck ! " The Prophet (ﷺ) said, " Leave him, for he has companions, and if you compare your prayers with their prayers and your fasting with theirs, you will look down upon your prayers and fasting, in comparison to theirs. Yet they will go out of the religion as an arrow darts through the game's body in which case, if the Qudhadh of the arrow is examined, nothing will be found on it, and when its Nasl is examined, nothing will be found on it; and then its Nadiyi is examined, nothing will be found on it. The arrow has been too fast to be smeared by dung and blood. The sign by which these people will be recognized will be a man whose one hand (or breast) will be like the breast of a woman (or like a moving piece of flesh). These people will appear when there will be differences among the people (Muslims)." Abu Sa`id added: I testify that I heard this from the Prophet (ﷺ) and also testify that `Ali killed those people while I was with him. The man with the description given by the Prophet (ﷺ) was brought to `Ali. The following Verses were revealed in connection with that very person (i.e., `Abdullah bin Dhil-Khawaisira at-Tarnimi): 'And among them are men who accuse you (O Muhammad) in the matter of (the distribution of) the alms}}
\hadithdefcmd{bukhari}{6934}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، حَدَّثَنَا يُسَيْرُ بْنُ عَمْرٍو، قَالَ قُلْتُ لِسَهْلِ بْنِ حُنَيْفٍ هَلْ سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فِي الْخَوَارِجِ شَيْئًا قَالَ سَمِعْتُهُ يَقُولُ ـ وَأَهْوَى بِيَدِهِ قِبَلَ الْعِرَاقِ ـ ‏ "‏ يَخْرُجُ مِنْهُ قَوْمٌ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ، يَمْرُقُونَ مِنَ الإِسْلاَمِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ ‏"‏‏.‏\hadithno{6934}\hadithtrans{Narrated Yusair bin `Amr:I asked Sahl bin Hunaif, "Did you hear the Prophet (ﷺ) saying anything about Al-Khawarij?" He said, "I heard him saying while pointing his hand towards Iraq. "There will appear in it (i.e, Iraq) some people who will recite the Qur'an but it will not go beyond their throats, and they will go out from (leave) Islam as an arrow darts through the game's body}}
\hadithdefcmd{bukhari}{6935}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَقْتَتِلَ فِئَتَانِ دَعْوَاهُمَا وَاحِدَةٌ ‏"‏‏.‏\hadithno{6935}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established till two (huge) groups fight against each other, their claim being one and the same}}
\hadithdefcmd{bukhari}{6936}{قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، وَعَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ الْقَارِيَّ، أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَمَعْتُ لِقِرَاءَتِهِ، فَإِذَا هُوَ يَقْرَؤُهَا عَلَى حُرُوفٍ كَثِيرَةٍ لَمْ يُقْرِئْنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم كَذَلِكَ، فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ فَانْتَظَرْتُهُ حَتَّى سَلَّمَ، ثُمَّ لَبَّبْتُهُ بِرِدَائِهِ أَوْ بِرِدَائِي فَقُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ قَالَ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ لَهُ كَذَبْتَ فَوَاللَّهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِي هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَؤُهَا‏.‏ فَانْطَلَقْتُ أَقُودُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ بِسُورَةِ الْفُرْقَانِ عَلَى حُرُوفٍ لَمْ تُقْرِئْنِيهَا، وَأَنْتَ أَقْرَأْتَنِي سُورَةَ الْفُرْقَانِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ يَا عُمَرُ، اقْرَأْ يَا هِشَامُ ‏"‏‏.‏ فَقَرَأَ عَلَيْهِ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَؤُهَا‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏‏.‏ فَقَرَأْتُ فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏‏.‏\hadithno{6936}\hadithtrans{Umar bin Al-Khattab said:I heard Hisham bin Al-Hakim reciting Surat Al-Furqan during the lifetime of Allah's Messenger (ﷺ). I listened to his recitation and noticed that he recited it in several different ways which Allah's Messenger (ﷺ) had not taught me. So I was about to jump over him during his Salat (prayer) but I waited till he finished his Salat (prayer) whereupon I put, either his upper garment or my upper garment around his neck and seized him by it and asked him, "Who has taught you this Surah?" He replied: "Allah's Messenger (ﷺ) has taught it to me." I said (to him), "You have told a lie! By Allah, Allah's Messenger (ﷺ) has taught me this Surah which I have heard you reciting." So I dragged him to the Allah's Messenger (ﷺ). I said: "O Allah's Messenger I have heard this man reciting Surat Al-Furqan in a way in which you have not taught me, and you did teach me Surah Al-Furqan." On that Allah's Messenger (ﷺ) said, "O 'Umar, release him! Recite, O Hisham". So Hisham recited before him in the way as I heard him reciting. Allah's Messenger (ﷺ) said, "It has been revealed like this." Then Allah's Messenger (ﷺ) said, "Recite, O 'Umar" So recited it. The Prophet (ﷺ) said, "It has been revealed like this." And then he added, "This Qur'an has been revealed to be recited in seven different ways, so recite it whichever way is easier for you}}
\hadithdefcmd{bukhari}{6937}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، ح حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، رضى الله عنه قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏الَّذِينَ آمَنُوا وَلَمْ يَلْبِسُوا إِيمَانَهُمْ بِظُلْمٍ‏\}‏ شَقَّ ذَلِكَ عَلَى أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَقَالُوا أَيُّنَا لَمْ يَظْلِمْ نَفْسَهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ كَمَا تَظُنُّونَ‏.‏ إِنَّمَا هُوَ كَمَا قَالَ لُقْمَانُ لاِبْنِهِ ‏\{‏يَا بُنَىَّ لاَ تُشْرِكْ بِاللَّهِ إِنَّ الشِّرْكَ لَظُلْمٌ عَظِيمٌ‏\}‏‏"‏‏.‏\hadithno{6937}\hadithtrans{Narrated `Abdullah:When the Verse:--'Those who believe and did not confuse their belief with wrong (worshipping others besides Allah).' (6.82) was revealed, it was hard on the companions of the Prophet (ﷺ) and they said, "Who among us has not wronged (oppressed) himself?" Allah's Messenger (ﷺ) said, "The meaning of the Verse is not as you think, but it is as Luqman said to his son, 'O my son! Join not in worship others with Allah, Verily! Joining others in worship with Allah is a great wrong indeed}}
\hadithdefcmd{bukhari}{6938}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، قَالَ سَمِعْتُ عِتْبَانَ بْنَ مَالِكٍ، يَقُولُ غَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ رَجُلٌ أَيْنَ مَالِكُ بْنُ الدُّخْشُنِ فَقَالَ رَجُلٌ مِنَّا ذَلِكَ مُنَافِقٌ لاَ يُحِبُّ اللَّهَ وَرَسُولَهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَ تَقُولُوهُ يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ يَبْتَغِي‏.‏ بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ قَالَ بَلَى‏.‏ قَالَ ‏"‏ فَإِنَّهُ لاَ يُوَافَى عَبْدٌ يَوْمَ الْقِيَامَةِ بِهِ إِلاَّ حَرَّمَ اللَّهُ عَلَيْهِ النَّارَ ‏"‏‏.‏\hadithno{6938}\hadithtrans{Narrated `Itban bin Malik:Once Allah's Messenger (ﷺ) came to me in the morning, and a man among us said, "Where is Malik bin Ad- Dukhshun?" Another man from us replied, "He is a hypocrite who does not love Allah and His Apostle." The Prophet (ﷺ) said, "Don't you think that he says: None has the right to be worshipped but Allah, only for Allah's sake?" They replied, "Yes" The Prophet (ﷺ) said, "Nobody will meet Allah with that saying on the Day of Resurrection, but Allah will save him from the Fire}}
\hadithdefcmd{bukhari}{6939}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنْ فُلاَنٍ، قَالَ تَنَازَعَ أَبُو عَبْدِ الرَّحْمَنِ وَحِبَّانُ بْنُ عَطِيَّةَ فَقَالَ أَبُو عَبْدِ الرَّحْمَنِ لِحِبَّانَ لَقَدْ عَلِمْتُ الَّذِي جَرَّأَ صَاحِبَكَ عَلَى الدِّمَاءِ يَعْنِي عَلِيًّا‏.‏ قَالَ مَا هُوَ لاَ أَبَا لَكَ قَالَ شَىْءٌ سَمِعْتُهُ يَقُولُهُ‏.‏ قَالَ مَا هُوَ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَالزُّبَيْرَ وَأَبَا مَرْثَدٍ وَكُلُّنَا فَارِسٌ قَالَ ‏"‏ انْطَلِقُوا حَتَّى تَأْتُوا رَوْضَةَ حَاجٍ ـ قَالَ أَبُو سَلَمَةَ هَكَذَا قَالَ أَبُو عَوَانَةَ حَاجٍ ـ فَإِنَّ فِيهَا امْرَأَةً مَعَهَا صَحِيفَةٌ مِنْ حَاطِبِ بْنِ أَبِي بَلْتَعَةَ إِلَى الْمُشْرِكِينَ فَأْتُونِي بِهَا ‏"‏‏.‏ فَانْطَلَقْنَا عَلَى أَفْرَاسِنَا حَتَّى أَدْرَكْنَاهَا حَيْثُ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم تَسِيرُ عَلَى بَعِيرٍ لَهَا، وَكَانَ كَتَبَ إِلَى أَهْلِ مَكَّةَ بِمَسِيرِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَيْهِمْ‏.‏ فَقُلْنَا أَيْنَ الْكِتَابُ الَّذِي مَعَكِ قَالَتْ مَا مَعِي كِتَابٌ‏.‏ فَأَنَخْنَا بِهَا بَعِيرَهَا، فَابْتَغَيْنَا فِي رَحْلِهَا فَمَا وَجَدْنَا شَيْئًا‏.‏ فَقَالَ صَاحِبِي مَا نَرَى مَعَهَا كِتَابًا‏.‏ قَالَ فَقُلْتُ لَقَدْ عَلِمْنَا مَا كَذَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ حَلَفَ عَلِيٌّ وَالَّذِي يُحْلَفُ بِهِ لَتُخْرِجِنَّ الْكِتَابَ أَوْ لأُجَرِّدَنَّكِ‏.‏ فَأَهْوَتْ إِلَى حُجْزَتِهَا وَهْىَ مُحْتَجِزَةٌ بِكِسَاءٍ فَأَخْرَجَتِ الصَّحِيفَةَ، فَأَتَوْا بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ قَدْ خَانَ اللَّهَ وَرَسُولَهُ وَالْمُؤْمِنِينَ‏.‏ دَعْنِي فَأَضْرِبَ عُنُقَهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا حَاطِبُ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَالِي أَنْ لاَ أَكُونَ مُؤْمِنًا بِاللَّهِ وَرَسُولِهِ، وَلَكِنِّي أَرَدْتُ أَنْ يَكُونَ لِي عِنْدَ الْقَوْمِ يَدٌ، يُدْفَعُ بِهَا عَنْ أَهْلِي وَمَالِي، وَلَيْسَ مِنْ أَصْحَابِكَ أَحَدٌ إِلاَّ لَهُ هُنَالِكَ مِنْ قَوْمِهِ مَنْ يَدْفَعُ اللَّهُ بِهِ عَنْ أَهْلِهِ وَمَالِهِ‏.‏ قَالَ ‏"‏ صَدَقَ، لاَ تَقُولُوا لَهُ إِلاَّ خَيْرًا ‏"‏‏.‏ قَالَ فَعَادَ عُمَرُ فَقَالَ يَا رَسُولُ اللَّهِ قَدْ خَانَ اللَّهَ وَرَسُولَهُ وَالْمُؤْمِنِينَ، دَعْنِي فَلأَضْرِبَ عُنُقَهُ‏.‏ قَالَ ‏"‏ أَوَلَيْسَ مِنْ أَهْلِ بَدْرٍ، وَمَا يُدْرِيكَ لَعَلَّ اللَّهَ اطَّلَعَ عَلَيْهِمْ فَقَالَ اعْمَلُوا مَا شِئْتُمْ فَقَدْ أَوْجَبْتُ لَكُمُ الْجَنَّةَ ‏"‏‏.‏ فَاغْرَوْرَقَتْ عَيْنَاهُ فَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏\hadithno{6939}\hadithtrans{Narrated:Abu `Abdur-Rahman and Hibban bin 'Atiyya had a dispute. Abu `Abdur-Rahman said to Hibban, "You know what made your companions (i.e. `Ali) dare to shed blood." Hibban said, "Come on! What is that?" `Abdur-Rahman said, "Something I heard him saying." The other said, "What was it?" `AbdurRahman said, "`Ali said, Allah's Messenger (ﷺ) sent for me, Az-Zubair and Abu Marthad, and all of us were cavalry men, and said, 'Proceed to Raudat-Hajj (Abu Salama said that Abu 'Awana called it like this, i.e., Hajj where there is a woman carrying a letter from Hatib bin Abi Balta'a to the pagans (of Mecca). So bring that letter to me.' So we proceeded riding on our horses till we overtook her at the same place of which Allah's Messenger (ﷺ) had told us. She was traveling on her camel. In that letter Hatib had written to the Meccans about the proposed attached of Allah's Messenger (ﷺ) against them. We asked her, "Where is the letter which is with you?' She replied, 'I haven't got any letter.' So we made her camel kneel down and searched her luggage, but we did not find anything. My two companions said, 'We do not think that she has got a letter.' I said, 'We know that Allah's Messenger (ﷺ) has not told a lie.'" Then `Ali took an oath saying, "By Him by Whom one should swear! You shall either bring out the letter or we shall strip off your clothes." She then stretched out her hand for her girdle (round her waist) and brought out the paper (letter). They took the letter to Allah's Messenger (ﷺ). `Umar said, "O Allah's Messenger (ﷺ)! (Hatib) has betrayed Allah, His Apostle and the believers; let me chop off his neck!" Allah's Messenger (ﷺ) said, "O Hatib! What obliged you to do what you have done?" Hatib replied, "O Allah's Messenger (ﷺ)! Why (for what reason) should I not believe in Allah and His Apostle? But I intended to do the (Mecca) people a favor by virtue of which my family and property may be protected as there is none of your companions but has some of his people (relatives) whom Allah urges to protect his family and property." The Prophet (ﷺ) said, "He has said the truth; therefore, do not say anything to him except good." `Umar again said, "O Allah's Messenger (ﷺ)! He has betrayed Allah, His Apostle and the believers; let me chop his neck off!" The Prophet (ﷺ) said, "Isn't he from those who fought the battle of Badr? And what do you know, Allah might have looked at them (Badr warriors) and said (to them), 'Do what you like, for I have granted you Paradise?' " On that, `Umar's eyes became flooded with tears and he said, "Allah and His Apostle know best}}
